@@ -2129,6 +2129,8 @@ static bool wait_conn(COMSTACK cs, int secs)
 {
     struct yaz_poll_fd pfd;
 
+    pfd.input_mask = yaz_poll_none;
+    pfd.output_mask = yaz_poll_none;
     yaz_poll_add(pfd.input_mask, yaz_poll_except);
     if (cs->io_pending & CS_WANT_WRITE)
         yaz_poll_add(pfd.input_mask, yaz_poll_write);
